OC.L10N.register(
    "notes",
    {
    "Notes" : "Noter",
    "The last viewed note cannot be accessed. " : "Den senest viste note kan ikke tilgås.",
    "The notes folder is not accessible: %s" : "Mappen med noter er ikke tilgængelig: %s",
    "Encryption Error" : "Fejl i kryptering",
    "Error" : "Fejl",
    "New note" : "Ny note",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Der er noter der ikke er gemt. Hvis du forlader denne side vil de blive smidt væk!",
    "Settings" : "Indstillinger",
    "Delete note" : "Slet note",
    "Saving failed!" : "Kunne ikke gemme!",
    "_%n word_::_%n words_" : ["%n ord","%n ord"]
},
"nplurals=2; plural=(n != 1);");
